@@ -21,7 +21,10 @@ logger.addHandler(con)
 tags={}
 def set_tags(key,value):
         tags[key]=value
-
+def merge_two_dicts(x, y):
+        z = x.copy()   # start with x's keys and values
+        z.update(y)    # modifies z with y's keys and values & returns None
+        return z
 def _log(msg, application, level,execution_time, user_id, extra_data):
         now =str( int(datetime.now().timestamp()))    
         environment = 'development' if config("ENVIRONMENT") == None or config("ENVIRONMENT")=="" else config("ENVIRONMENT")
@@ -37,7 +40,7 @@ def _log(msg, application, level,execution_time, user_id, extra_data):
             "extra_data": extra_data,
             "timestamp": now
         }
-        data={**original_data, **tags}
+        data=merge_two_dicts(original_data, tags)
 
         handler = logging.FileHandler(config('DIR')+now+'.log')
         handler.setLevel(logging.INFO)
